<?php 
/*
Plugin Name: Holler
Plugin URI: http://jamietalbot.com/wp-hacks/holler/
Description: AJAX powered contact form for WordPress.<br/>Licensed under the <a href="http://www.opensource.org/licenses/mit-license.php">MIT License</a>, Copyright &copy; 2005-2006 Jamie Talbot.
Version: 0.9
Author: Jamie Talbot
Author URI: http://jamietalbot.com/
*/ 

/*
Holler - AJAX powered contact form for WordPress.
Copyright (c) 2005-2006 Jamie Talbot

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the
Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to
do so, subject to the following conditions:

The above copyright notice and this permission notice shall
be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

define ("HOLLER_DIR", "/wp-content/plugins/holler");

// Load some variables for the server side script.
if (!defined('ABSPATH')) require_once('../../../wp-blog-header.php');

load_plugin_textdomain('holler', HOLLER_DIR);

define ("HOLLER_NO_NAME", 1);
define ("HOLLER_NO_EMAIL", 2);
define ("HOLLER_BAD_EMAIL", 3);
define ("HOLLER_NO_MESSAGE", 4);
define ("HOLLER_MAIL_FAILED", 5);
define ("HOLLER_SUCCESS", 6);
define ("HOLLER_DEFAULT", 7);
define ("HOLLER_NO_MULTIPLES", 8);

// Change these to alter how holler marks up the returned messages 
// to integrate it with your theme.
define ("HOLLER_SUCCESS_WRAPPER_OPEN", '<p class=\"holler_success\">');
define ("HOLLER_SUCCESS_WRAPPER_CLOSE", '</p>');
define ("HOLLER_ERROR_WRAPPER_OPEN", '<p class=\"holler_error\">');
define ("HOLLER_ERROR_WRAPPER_CLOSE", '</p>');
define ("HOLLER_DEFAULT_WRAPPER_OPEN", '<p>');
define ("HOLLER_DEFAULT_WRAPPER_CLOSE", '</p>');

// Change these to the addresses you want to appear as send options.
// Make sure there is a comma at the end of every line, except the last one.
// The first half of each entry is the mail alias which will be displayed in 
// the form so that your address cannot be scraped.  Make sure there is at least
// one alias/address pair or the form will not display.
$holler_addresses = array
(
'EXAMPLE' => 'you@youraddress.com',
'EXAMPLE2' => '2ndemail@somewhere.com'
);

// Feel free to customise these messages to fit in with your theme.
$holler_messages = array
(
HOLLER_NO_NAME => __('Please enter a name so we know who you are!', 'holler'),
HOLLER_NO_EMAIL => __('Please enter an email so we can contact you!', 'holler'),
HOLLER_BAD_EMAIL => __('Please enter a valid email address.', 'holler'),
HOLLER_NO_MESSAGE => __('You didn\'t enter anything!', 'holler'),
HOLLER_MAIL_FAILED => __('Sorry, there was a problem sending your message.', 'holler'),
HOLLER_SUCCESS => __('Thanks for your message!  We\'ll get back to you as soon as we can.', 'holler'),
HOLLER_DEFAULT => __('Choose an email address from the list and send a message!', 'holler'),
HOLLER_NO_TO => __('The contact form has not been configured properly.', 'holler'),
HOLLER_NO_MULTIPLES => __('You cannot have multiple copies of Holler on the same page.', 'holler')
);

// Prevent multiple copies of Holler appearing on the same page.
$holler_displayed = false;

// You probably shouldn't change anything below here unless you know what you 
// are doing!
function holler_server() 
{
	global $holler_messages;
	global $holler_addresses;

  $name = stripslashes($_POST['holler_name']);
  if (!$name) return '-' . HOLLER_ERROR_WRAPPER_OPEN . $holler_messages[HOLLER_NO_NAME] . HOLLER_ERROR_WRAPPER_CLOSE;
  $from = $_POST['holler_address'];
  if (!$from) return '-' . HOLLER_ERROR_WRAPPER_OPEN . $holler_messages[HOLLER_NO_EMAIL] . HOLLER_ERROR_WRAPPER_CLOSE;
  $message = $_POST['holler_message'];
  if (!$message) return '-' . HOLLER_ERROR_WRAPPER_OPEN . $holler_messages[HOLLER_NO_MESSAGE] . HOLLER_ERROR_WRAPPER_CLOSE;
  $subject = $_POST['holler_subject'];
  if (!$subject) $subject = sprintf(__("Message from %s (Holler - %s)", 'holler'), $name, get_settings('siteurl'));
  if (!$message) return '-' . HOLLER_ERROR_WRAPPER_OPEN . $holler_messages[HOLLER_NO_MESSAGE] . HOLLER_ERROR_WRAPPER_CLOSE;


  if (!is_email($from)) return '-' . HOLLER_ERROR_WRAPPER_OPEN . $holler_messages[HOLLER_BAD_EMAIL] . HOLLER_ERROR_WRAPPER_CLOSE;
  $message = stripslashes($_POST['holler_message']);
	$to = $holler_addresses[$_POST['holler_to']];

  $headers = "MIME-Version: 1.0\n";
	$headers .= "From: $from\n";
	$headers .= "Content-Type: text/plain; charset=\"" . get_settings('blog_charset') . "\"\n";
  if ("true" == $_POST['holler_cc']) $headers .= "CC: $from\n";
  if (wp_mail($to, $subject, $message, $headers) == 1) return '+' . HOLLER_SUCCESS_WRAPPER_OPEN . $holler_messages[HOLLER_SUCCESS] . HOLLER_SUCCESS_WRAPPER_CLOSE;
	else return '-' . HOLLER_ERROR_WRAPPER_OPEN . $holler_messages[HOLLER_MAIL_FAILED] . HOLLER_ERROR_WRAPPER_CLOSE;
}

function holler($inline = false)
{
	global $holler_addresses;
	global $holler_messages;
	global $holler_displayed;
	
	if ($holler_displayed) return "<div id=\"holler_response\">" . HOLLER_ERROR_WRAPPER_OPEN . $holler_messages[HOLLER_NO_MULTIPLES] . HOLLER_ERROR_WRAPPER_CLOSE . "</div>";
	$holler_displayed = true;
	if ($inline) ob_start();
?>
	<!-- Holler - AJAX powered contact form for WordPress. -->
	<!-- Copyright (c) 2005-2006 Jamie Talbot -->
	<script type="text/javascript" src="<?php echo get_settings('siteurl') ?>/wp-includes/js/tw-sack.js"></script>
	<script type="text/javascript" src="<?php echo get_settings('siteurl') . HOLLER_DIR ?>/holler_javascript.php"></script>
	<?php if (count($holler_addresses))
	{
	?>
	<div id="holler_response"><?php echo HOLLER_DEFAULT_WRAPPER_OPEN . $holler_messages[HOLLER_DEFAULT] . HOLLER_DEFAULT_WRAPPER_CLOSE ?></div>
	<form id="holler" action="">
	<p>
		<?php if (count($holler_addresses) > 1)
		{
		?>
	<select id="holler_to">
			<?php
			foreach ($holler_addresses as $alias => $address)
			{
			?>
	<option value="<?php echo $alias ?>"><?php echo $alias ?></option>
			<?php
			}
			?>
	</select>
		<?php
		}
		else
		{
		?>
	<input id="holler_to" type="hidden" value="<?php echo key($holler_addresses) ?>" />
		<?php
		}
		?>
	</p>
	<p><label for="holler_name"><?php _e('Name:', 'holler') ?></label><br /><input class="textbox" id="holler_name" /></p>
	<p><label for="holler_address"><?php _e('Email:', 'holler') ?></label><br /><input class="textbox" id="holler_address" /></p>
	<p><label for="holler_subject"><?php _e('Subject:', 'holler') ?></label><br /><input class="textbox" id="holler_subject" /></p>
	<p><label for="holler_message"><?php _e('Message:', 'holler') ?></label><br /><textarea id="holler_message" rows="10" cols="10"></textarea></p>
	<p><input id="holler_cc" type="checkbox" /><label for="holler_cc"> <?php _e('Send a copy to yourself', 'holler') ?></label></p>
	<p><input type="button" value="<?php _e('Send Message', 'holler') ?>" onclick="holler_out()" />
	</p>
	</form>
	<?php
	}
	else
	{
	?>
	<div id="holler_response"><?php echo HOLLER_ERROR_WRAPPER_OPEN . $holler_messages[HOLLER_NO_TO] . HOLLER_ERROR_WRAPPER_CLOSE ?></div>
	<?php
	}
	if ($inline) return ob_get_clean();
}

// Allow a user to put a contact form inside a post.
function holler_inline($content)
{
	if(!preg_match('|<!--holler-->|', $content)) return $content;	
	return str_replace('<!--holler-->', holler(true), $content);
}

if (isset($_POST['holler']) && (true == $_POST['holler']))
{
	echo holler_server();
	exit;
}

add_action('the_content', 'holler_inline', 8);

?>